@@ -92,16 +92,28 @@ class Camera(BaseCamera):
         cc = v4lc.V4L2_CTL("/dev/video"+str(vidnum))
         capa = cc.get_capbilities()
 
-        expo_auto = cc.get_exposure_auto()
-        expo_autodef = cc.getdef_exposure_auto()
-        exposure_absolute = cc.get_exposure_absolute()
+
+        # very stupid camera    ZC0303 Webcam
+        if "exposure" in capa:
+            exposure = cc.get_exposure()
+            exposuredef = cc.getdef_exposure()
+            print(f"i... EXPOAUTO == {exposure} vs def={exposuredef}; ")
+
+
+        if "exposure_auto" in capa:
+            expo_auto = cc.get_exposure_auto()
+            expo_autodef = cc.getdef_exposure_auto()
+            print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef}; ")
+
+        if "exposure_absolute" in capa:
+            exposure_absolute = cc.get_exposure_absolute()
+
         if "gain" in capa:
             gain = cc.get_gain()
             gaindef = cc.getdef_gain()
         if "gamma" in capa:
             gamma = cc.get_gamma()
             gammadef = cc.getdef_gamma()
-        print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef}; ")
 
 
         nfrm = 0
@@ -177,8 +189,14 @@ class Camera(BaseCamera):
                         exposure_absolute = 100
                         expo_auto = 3
                         expo_autodef = 3
+
+
+                        # very stupid camera    ZC0303 Webcam - parallel to exposure_auto
+                        if "exposure" in capa:
+                            exposure = cc.get_exposure()
+
                         # --- crashing with C120
-                        if "exposure_auto" in capa:
+                        if "exposure_auto" in capa:  # if not auto, always tell _absolute
                             expo_auto = cc.get_exposure_auto()
                             expo_autodef = cc.getdef_exposure_auto()
 
@@ -227,8 +245,15 @@ class Camera(BaseCamera):
                         senh.setbox(f"his {hmean:3.0f}",  senh.hist)
 
 
-                    if expo_auto!=expo_autodef: # manual
-                        senh.setbox(f"expo {exposure_absolute}",  senh.expo)
+                    # very stupid camera    ZC0303 Webcam
+                    if "exposure" in capa:
+                        if exposure!=exposuredef: # manual
+                            senh.setbox(f"expo {exposure}",  senh.expo)
+
+
+                    if "exposure_auto" in capa:
+                        if expo_auto!=expo_autodef: # manual
+                            senh.setbox(f"expo {exposure_absolute}",  senh.expo)
                     if ("gain" in capa) and (gain!=gaindef): # gain is not frequently tunable
                         senh.setbox(f"g {gain}",  senh.gain)
                     if ("gamma" in capa):
