@@ -190,7 +190,7 @@ class V4L2_CTL():
         CMD = ['which','v4l2-ctl']
         child = sp.Popen( CMD, stdout = sp.PIPE )
         returncode = child.returncode
-        print(f"i... v4l2-ctl:", returncode, 'str=',child.communicate()[0] )
+        # print(f"i... v4l2-ctl:", returncode, 'str=',child.communicate()[0] )
         if not(returncode is None):
             print("X... install v4l2-ctl:  apt install v4l-utils")
             sys.exit(1)
